@@ -5,9 +5,10 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum, x0.1, p.x0, inflate0,
          scale.unif, scale.halft, link, n.chain, inits, seed) 
 { 
   dataIn <- vector("list",19)
-  dataIn.name <- c("n","y","q","xmu.1","p.xmu","xsum.1","p.xsum","x0.1","p.x0",
-                   "inflate0","zero","link","hyper","prior1","prior2","rid",
-                   "EUID","nEU","hyper2")
+  dataIn.name <- c("n","y","q","xmu.1","p.xmu",
+                   "xsum.1","p.xsum","x0.1","p.x0","inflate0",
+                   "zero","link","hyper","prior1","prior2",
+                   "rid", "EUID","nEU","hyper2")
   names(dataIn)<- dataIn.name 
   dataIn[[1]] <- n      
   dataIn[[2]] <- as.matrix(y)
@@ -22,13 +23,13 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum, x0.1, p.x0, inflate0,
   dataIn[[11]]<- matrix(0,n,q)  
   dataIn[[12]]<- link 
   dataIn[[13]]<- abind(prec.int,prec.DN,lambda.L1,lambda.L2,lambda.ARD,along=3)    
-  if(grepl("unif", prior.Sigma)) dataIn[[19]] <- scale.unif
-  if(grepl("halfcauchy",prior.Sigma)) dataIn[[19]] <- scale.halft                    
   dataIn[[14]] <- prior1
   dataIn[[15]] <- prior2    
   dataIn[[16]] <- rid 
   dataIn[[17]] <- EUID
   dataIn[[18]] <- nEU
+  if(grepl("unif", prior.Sigma)) dataIn[[19]] <- scale.unif
+  if(grepl("halfcauchy",prior.Sigma)) dataIn[[19]] <- scale.halft           
   
   if(is.null(seed)){
     init <- function( rngname, rngseed){    
@@ -41,12 +42,12 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum, x0.1, p.x0, inflate0,
            "b0.tmp"= array(rnorm((p.x0-1)*4*q,0,0.1),  c((p.x0-1),q,4)),
            
            "sigmab.L1" =  matrix(runif((p.xmu-1)*q,0,2),(p.xmu-1),q), 
-           "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
-           "sigmab0.L1" = matrix(runif((p.x0-1)*q,0,2),(p.xmu-1),q),  
+           "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
+           "sigmab0.L1" = matrix(runif((p.x0-1)*q,0,2),(p.x0-1),q),  
            
            "taub.ARD" =  matrix(runif((p.xmu-1)*q,0,2), (p.xmu-1),q), 
-           "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
-           "taub0.ARD" = matrix(runif((p.x0-1)*q,0 ,2),(p.xmu-1),q),  
+           "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
+           "taub0.ARD" = matrix(runif((p.x0-1)*q,0 ,2),(p.x0-1),q),  
            
            "taub.L2" =  runif(q,0,2), 
            "taud.L2" =  runif(q,0,2),
@@ -69,12 +70,12 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum, x0.1, p.x0, inflate0,
          "b0.tmp"= array(rnorm((p.x0-1)*4*q,0,0.1),  c((p.x0-1),q,4)),
          
          "sigmab.L1" =  matrix(runif((p.xmu-1)*q,0,2),(p.xmu-1),q), 
-         "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
-         "sigmab0.L1" = matrix(runif((p.x0-1)*q,0,2),(p.xmu-1),q),  
+         "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
+         "sigmab0.L1" = matrix(runif((p.x0-1)*q,0,2),(p.x0-1),q),  
          
          "taub.ARD" =  matrix(runif((p.xmu-1)*q,0,2), (p.xmu-1),q), 
-         "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
-         "taub0.ARD" = matrix(runif((p.x0-1)*q,0 ,2),(p.xmu-1),q),  
+         "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
+         "taub0.ARD" = matrix(runif((p.x0-1)*q,0 ,2),(p.x0-1),q),  
          
          "taub.L2" =  runif(q,0,2), 
          "taud.L2" =  runif(q,0,2),
@@ -113,6 +114,7 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum, x0.1, p.x0, inflate0,
       inits.internal[[i]][[17]]<- inits[[i]]$sigma}
   }}
   op<- system.file("bugs", "joint_1z0.bug", package="zoib") 
+  
   model <- jags.model(op,n.adapt=0, data=dataIn, inits=inits.internal, n.chains=n.chain)   
   return(model)
 }
